package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.CharacterMarkerSymbol;
import com.esri.arcgis.display.IColor;
import com.esri.arcgis.support.ms.stdole.Font;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads character marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class CharacterMarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(CharacterMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private CharacterMarkerSymbol symbol;

    public CharacterMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof CharacterMarkerSymbol) {
            this.symbol = (CharacterMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a CharacterMarkerSymbol!");
        }
    }

    public CharacterMarkerSymbolReader(IMarkerSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof CharacterMarkerSymbol) {
            this.symbol = (CharacterMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a CharacterMarkerSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        IColor c = symbol.getColor();
        symbolElement.setAttribute(
            "angle",
            String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute(
            "size",
            String.valueOf(symbol.getSize()));
        symbolElement.setAttribute(
            "x_offset",
            String.valueOf(symbol.getXOffset()));
        symbolElement.setAttribute(
            "y_offset",
            String.valueOf(symbol.getYOffset()));
        symbolElement.setAttribute(
            "color",
            String.valueOf(c.getRGB()));
        symbolElement.setAttribute(
            "tranparency",
            String.valueOf(c.getTransparency()));
        symbolElement.setAttribute(
            "name",
            symbol.getNameString());
        symbolElement.setAttribute(
            "char",
            String.valueOf(symbol.getCharacterIndex()));

        Font f = symbol.getFont();
        symbolElement.setAttribute("font", f.getName());
        symbolElement.setAttribute("char_set", String.valueOf(f.getCharset()));
        symbolElement.setAttribute("bold", String.valueOf(f.getBold()));
        symbolElement.setAttribute("italic", String.valueOf(f.getItalic()));
        symbolElement.setAttribute("font_size", String.valueOf(f.getSize()));
        symbolElement.setAttribute(
            "strike_through",
            String.valueOf(f.getStrikethrough()));
        symbolElement.setAttribute("weight", String.valueOf(f.getWeight()));
        symbolElement.setAttribute("style", "char");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
